@@ -2,9 +2,11 @@
 Launches the GUI application
 """
 
-from mirumoji.gui.main import app, setup_logging, PORT
+from mirumoji.gui.main import (app,
+                               setup_logging,
+                               PORT
+                               )
 from flaskwebgui import FlaskUI
-from multiprocessing import freeze_support
 
 
 def main():
@@ -23,5 +25,4 @@ def main():
 
 
 if __name__ == "__main__":
-    freeze_support()
     main()
